@@ -23,6 +23,9 @@ var class_ogre_1_1_d3_d11_render_window_base =
     [ "setFSAA", "class_ogre_1_1_d3_d11_render_window_base.html#a1227153f05335a568442005575606d52", null ],
     [ "isClosed", "class_ogre_1_1_d3_d11_render_window_base.html#a7d3b9733299948a95c0202f40f7400ef", null ],
     [ "isHidden", "class_ogre_1_1_d3_d11_render_window_base.html#a62fc766a70a6f080caf04f4387b85f3b", null ],
+    [ "getNumberOfViews", "class_ogre_1_1_d3_d11_render_window_base.html#a4d649c920d88a16e32ee0f41b2787dd7", null ],
+    [ "getSurface", "class_ogre_1_1_d3_d11_render_window_base.html#a65ef6e13fbebea8a57cff591ade58baa", null ],
+    [ "getRenderTargetView", "class_ogre_1_1_d3_d11_render_window_base.html#a3b6c7bc5f88715890af495e60e32e80d", null ],
     [ "getCustomAttribute", "class_ogre_1_1_d3_d11_render_window_base.html#a29736a92be98f4df51ee5c51f0f0e0d9", null ],
     [ "copyContentsToMemory", "class_ogre_1_1_d3_d11_render_window_base.html#aed998d281e1f82753372e3a457fa366b", null ],
     [ "requiresTextureFlipping", "class_ogre_1_1_d3_d11_render_window_base.html#a35573c92ede05be6fde674d8928057ef", null ],
