@@ -19,7 +19,7 @@ var class_ogre_1_1_d3_d11_texture =
     [ "~D3D11Texture", "class_ogre_1_1_d3_d11_texture.html#a0a2b64741a2cdaec8b5f62d80ccf4dfe", null ],
     [ "copyToTexture", "class_ogre_1_1_d3_d11_texture.html#ab3f5c3f62eb8d9e4d7c428c049e62991", null ],
     [ "getTextureResource", "class_ogre_1_1_d3_d11_texture.html#a323ab3dc288725c57fcf166b13b5cbf3", null ],
-    [ "getTexture", "class_ogre_1_1_d3_d11_texture.html#a6bec8b930d9233a8b71c77d7d8e9ae13", null ],
+    [ "getSrvView", "class_ogre_1_1_d3_d11_texture.html#aac612a4f38964be86c38ded135265067", null ],
     [ "getShaderResourceViewDesc", "class_ogre_1_1_d3_d11_texture.html#a7f50e41e95d8b4e9bcec1e585eccc784", null ],
     [ "GetTex1D", "class_ogre_1_1_d3_d11_texture.html#ae2c201852391e6bb54c3d83d4fc4c7a9", null ],
     [ "GetTex2D", "class_ogre_1_1_d3_d11_texture.html#a7a05622b98bae504dc5869d48997c642", null ],
@@ -64,12 +64,12 @@ var class_ogre_1_1_d3_d11_texture =
     [ "setTreatLuminanceAsAlpha", "class_ogre_1_1_d3_d11_texture.html#a963616fe631db2b5bef45234a15bff7f", null ],
     [ "getTreatLuminanceAsAlpha", "class_ogre_1_1_d3_d11_texture.html#af10046684f1810855fdc76bde88ec8d6", null ],
     [ "getNumFaces", "class_ogre_1_1_d3_d11_texture.html#a31d04160addb56e190c5155c21f998bf", null ],
-    [ "getBuffer", "class_ogre_1_1_d3_d11_texture.html#a7ebc51ffe79ea6bffd8ea45f1faf53c7", null ],
+    [ "getBuffer", "class_ogre_1_1_d3_d11_texture.html#a1381484c57cf3d8f2f480c834f164950", null ],
     [ "convertToImage", "class_ogre_1_1_d3_d11_texture.html#a6c5c6be0ec434481a055ab6b03b644fd", null ],
     [ "getCustomAttribute", "class_ogre_1_1_d3_d11_texture.html#accfa5467ab8ccfc5920ec64101f8f532", null ],
     [ "getCustomAttribute", "class_ogre_1_1_d3_d11_texture.html#a4b257658297582848fe47a027f75bb3a", null ],
     [ "createShaderAccessPoint", "class_ogre_1_1_d3_d11_texture.html#ad233adde489a5b2129eb20fc93952839", null ],
-    [ "createShaderAccessPoint", "class_ogre_1_1_d3_d11_texture.html#a2f3077804bdbef1f118c415c23f05a67", null ],
+    [ "setLayerNames", "class_ogre_1_1_d3_d11_texture.html#aa539a94d1bd9ea8f4e804093be538c3e", null ],
     [ "prepare", "class_ogre_1_1_d3_d11_texture.html#a350b287fa3e83a389221274f68760008", null ],
     [ "load", "class_ogre_1_1_d3_d11_texture.html#a699d1c851f494a8d5d23d23b695ceb47", null ],
     [ "reload", "class_ogre_1_1_d3_d11_texture.html#a5016aec1762b026997ddd346775879ef", null ],
