@@ -56,7 +56,6 @@ var class_ogre_1_1_g_l_e_s2_render_system =
     [ "bindGpuProgram", "group___g_l_e_s2.html#gad1b0cf3f7aea1a2f2bb3d8762500282f", null ],
     [ "unbindGpuProgram", "group___g_l_e_s2.html#ga564175c3cb628ac2deeea6d98d4e4bc0", null ],
     [ "bindGpuProgramParameters", "group___g_l_e_s2.html#ga9c3c59236b71f033101d6d63f1e2af94", null ],
-    [ "bindGpuProgramPassIterationParameters", "group___g_l_e_s2.html#ga9fe72776eaa2437f5a1ad7a2498de7cd", null ],
     [ "_setSeparateSceneBlending", "group___g_l_e_s2.html#ga2ed07f074ae69826c8090cd8541b67a5", null ],
     [ "_setAlphaRejectSettings", "group___g_l_e_s2.html#ga817c719f6b647354c82559324ecbdc39", null ],
     [ "getDisplayMonitorCount", "group___g_l_e_s2.html#ga3f58ee26c14bf54639eb2cdaf054c11b", null ],
@@ -137,6 +136,7 @@ var class_ogre_1_1_g_l_e_s2_render_system =
     [ "getCapabilities", "class_ogre_1_1_g_l_e_s2_render_system.html#ac4b66fe49129476323eba9bdca672a36", null ],
     [ "getDriverVersion", "class_ogre_1_1_g_l_e_s2_render_system.html#a884fc9154ef8f4c1d17a7920460d81f2", null ],
     [ "_getDefaultViewportMaterialScheme", "class_ogre_1_1_g_l_e_s2_render_system.html#aeb912c6c0bfc8bd8d0670448e0a5370a", null ],
+    [ "bindGpuProgramPassIterationParameters", "class_ogre_1_1_g_l_e_s2_render_system.html#aabc0921eddca002596bf37c22ef7b20c", null ],
     [ "isGpuProgramBound", "class_ogre_1_1_g_l_e_s2_render_system.html#a6077b61e7511ae56887c67498f5282a1", null ],
     [ "getNativeShadingLanguageVersion", "class_ogre_1_1_g_l_e_s2_render_system.html#a9d89d5e2e2f0c2c30e72032eae4482ec", null ],
     [ "setClipPlanes", "class_ogre_1_1_g_l_e_s2_render_system.html#a23cc0a7d87b77ec3d0a34e92335bec1a", null ],
