@@ -6,7 +6,6 @@ var class_ogre_1_1_gpu_program_parameters =
     [ "GpuSharedParamUsageList", "class_ogre_1_1_gpu_program_parameters.html#aa222ed139d2bffd3bc2d1d1793b253d0", null ],
     [ "SubroutineMap", "class_ogre_1_1_gpu_program_parameters.html#ac12c761cceb82bee686f3ca57b8c3686", null ],
     [ "SubroutineIterator", "class_ogre_1_1_gpu_program_parameters.html#a6537ab0e6ef6ce0da99a8093553fb18e", null ],
-    [ "AutoConstantIterator", "class_ogre_1_1_gpu_program_parameters.html#ab4d7fa4e86c8f3f0bb4ef73787034e15", null ],
     [ "AutoConstantType", "class_ogre_1_1_gpu_program_parameters.html#a155c886f15e0c10d2c33c224f0d43ce3", [
       [ "ACT_WORLD_MATRIX", "class_ogre_1_1_gpu_program_parameters.html#a155c886f15e0c10d2c33c224f0d43ce3a551bcc97ad47d0d2369f90176f0d5499", null ],
       [ "ACT_INVERSE_WORLD_MATRIX", "class_ogre_1_1_gpu_program_parameters.html#a155c886f15e0c10d2c33c224f0d43ce3a5ac8fc4f08f9563ca4198690977a70c4", null ],
@@ -32,6 +31,7 @@ var class_ogre_1_1_gpu_program_parameters =
       [ "ACT_INVERSE_WORLDVIEW_MATRIX", "class_ogre_1_1_gpu_program_parameters.html#a155c886f15e0c10d2c33c224f0d43ce3af9e09996569a0837f9d40e14f95e6913", null ],
       [ "ACT_TRANSPOSE_WORLDVIEW_MATRIX", "class_ogre_1_1_gpu_program_parameters.html#a155c886f15e0c10d2c33c224f0d43ce3a5333452f394b1d27734976283d2f8b83", null ],
       [ "ACT_INVERSE_TRANSPOSE_WORLDVIEW_MATRIX", "class_ogre_1_1_gpu_program_parameters.html#a155c886f15e0c10d2c33c224f0d43ce3ad2369aeaa2f99b64f9a918c4ad88ead8", null ],
+      [ "ACT_NORMAL_MATRIX", "class_ogre_1_1_gpu_program_parameters.html#a155c886f15e0c10d2c33c224f0d43ce3a94cc7e4643891042ccd0d568f6a836cc", null ],
       [ "ACT_WORLDVIEWPROJ_MATRIX", "class_ogre_1_1_gpu_program_parameters.html#a155c886f15e0c10d2c33c224f0d43ce3afeced027adb8bf0998e8593c70c57f7c", null ],
       [ "ACT_INVERSE_WORLDVIEWPROJ_MATRIX", "class_ogre_1_1_gpu_program_parameters.html#a155c886f15e0c10d2c33c224f0d43ce3ab9125fd298ad231580927ff6f522edfe", null ],
       [ "ACT_TRANSPOSE_WORLDVIEWPROJ_MATRIX", "class_ogre_1_1_gpu_program_parameters.html#a155c886f15e0c10d2c33c224f0d43ce3abb469c45232404f42ae0227f9c29baf9", null ],
@@ -88,6 +88,7 @@ var class_ogre_1_1_gpu_program_parameters =
       [ "ACT_SHADOW_EXTRUSION_DISTANCE", "class_ogre_1_1_gpu_program_parameters.html#a155c886f15e0c10d2c33c224f0d43ce3adda3368c87d6419c65a0e84e67de01e1", null ],
       [ "ACT_CAMERA_POSITION", "class_ogre_1_1_gpu_program_parameters.html#a155c886f15e0c10d2c33c224f0d43ce3a1c01f3dedf322354b9fc7fb0ca4630f3", null ],
       [ "ACT_CAMERA_POSITION_OBJECT_SPACE", "class_ogre_1_1_gpu_program_parameters.html#a155c886f15e0c10d2c33c224f0d43ce3abc344f70b801f5444c203e13eaf7a697", null ],
+      [ "ACT_CAMERA_RELATIVE_POSITION", "class_ogre_1_1_gpu_program_parameters.html#a155c886f15e0c10d2c33c224f0d43ce3a27ba3d019161b18082bce7bc5d69c8b4", null ],
       [ "ACT_TEXTURE_VIEWPROJ_MATRIX", "class_ogre_1_1_gpu_program_parameters.html#a155c886f15e0c10d2c33c224f0d43ce3ad50ba1a2f15aaa8abf8532c8c35c57e3", null ],
       [ "ACT_TEXTURE_VIEWPROJ_MATRIX_ARRAY", "class_ogre_1_1_gpu_program_parameters.html#a155c886f15e0c10d2c33c224f0d43ce3ac9f70d92017b588a32f221b057052318", null ],
       [ "ACT_TEXTURE_WORLDVIEWPROJ_MATRIX", "class_ogre_1_1_gpu_program_parameters.html#a155c886f15e0c10d2c33c224f0d43ce3a33ec9ff8f0e9e9e548356bfac6475893", null ],
@@ -159,7 +160,6 @@ var class_ogre_1_1_gpu_program_parameters =
     [ "operator=", "class_ogre_1_1_gpu_program_parameters.html#a707d1d61ad8afe4e43548c7a9d76a061", null ],
     [ "_setNamedConstants", "class_ogre_1_1_gpu_program_parameters.html#a3f34a7706fda7853a3e7a2d6f1351f9c", null ],
     [ "_setLogicalIndexes", "class_ogre_1_1_gpu_program_parameters.html#a8153e76904138fe948ed03cdd304d438", null ],
-    [ "_setLogicalIndexes", "class_ogre_1_1_gpu_program_parameters.html#a3d7c63786136fb080b915e9f29d04cf3", null ],
     [ "hasNamedParameters", "class_ogre_1_1_gpu_program_parameters.html#a790f2419a84bb60b2eaf04fb10bba726", null ],
     [ "hasLogicalIndexedParameters", "class_ogre_1_1_gpu_program_parameters.html#af65aea391537800c502dfc1306ffc00b", null ],
     [ "setConstant", "class_ogre_1_1_gpu_program_parameters.html#a8256ff15f5b4aef94fd1697edb0dff0e", null ],
@@ -187,7 +187,8 @@ var class_ogre_1_1_gpu_program_parameters =
     [ "_writeRawConstant", "class_ogre_1_1_gpu_program_parameters.html#a2b1d6007af15db665a78fae79411a463", null ],
     [ "_writeRawConstant", "class_ogre_1_1_gpu_program_parameters.html#ade8223cfd36836dde883ee33329415cc", null ],
     [ "_writeRawConstant", "class_ogre_1_1_gpu_program_parameters.html#ab61caa3184e94b6b9a22ab3d788ddbab", null ],
-    [ "_writeRawConstant", "class_ogre_1_1_gpu_program_parameters.html#a69a807e788cd434aaee00dab135e5ef8", null ],
+    [ "_writeRawConstant", "class_ogre_1_1_gpu_program_parameters.html#a0e001a38ed0a7f086f6589b708dfd5a4", null ],
+    [ "_writeRawConstant", "class_ogre_1_1_gpu_program_parameters.html#a55667cc8aafb889e3ceb2acff0d0d303", null ],
     [ "_writeRawConstant", "class_ogre_1_1_gpu_program_parameters.html#aef013f2e84ba942d122d5ac2802abd78", null ],
     [ "getConstantDefinitionIterator", "class_ogre_1_1_gpu_program_parameters.html#afb07c7d6b8de0b8da8b5365a7fa33831", null ],
     [ "getConstantDefinition", "class_ogre_1_1_gpu_program_parameters.html#af6716229b90ea003ad875deb108b9c65", null ],
@@ -195,13 +196,9 @@ var class_ogre_1_1_gpu_program_parameters =
     [ "getFloatLogicalBufferStruct", "class_ogre_1_1_gpu_program_parameters.html#a47211d40ae8e8a282181c5a16648ef7c", null ],
     [ "getDoubleLogicalBufferStruct", "class_ogre_1_1_gpu_program_parameters.html#a7caa3c97cdf876b9e220ac37f2119fef", null ],
     [ "getIntLogicalBufferStruct", "class_ogre_1_1_gpu_program_parameters.html#acc006af0b4a695db6b22a603d4c60f8a", null ],
-    [ "getUnsignedIntLogicalBufferStruct", "class_ogre_1_1_gpu_program_parameters.html#a3dcb44ff1d6a1de275268e876b9756f2", null ],
-    [ "getBoolLogicalBufferStruct", "class_ogre_1_1_gpu_program_parameters.html#a5ee02f3913c184877e1be7a3843012fb", null ],
     [ "getFloatLogicalIndexForPhysicalIndex", "class_ogre_1_1_gpu_program_parameters.html#a07aa2e617946e27ad84f152974f668d1", null ],
     [ "getDoubleLogicalIndexForPhysicalIndex", "class_ogre_1_1_gpu_program_parameters.html#a2811094c5f8c3e7c0bfec33be04ad6a5", null ],
     [ "getIntLogicalIndexForPhysicalIndex", "class_ogre_1_1_gpu_program_parameters.html#a60f25f4c949f6d903174f4b795a130be", null ],
-    [ "getUnsignedIntLogicalIndexForPhysicalIndex", "class_ogre_1_1_gpu_program_parameters.html#ae29a417c731fcab5ffb8c151696e2b94", null ],
-    [ "getBoolLogicalIndexForPhysicalIndex", "class_ogre_1_1_gpu_program_parameters.html#a08aabe2c4b46d6d3c0d8e7d11546ced7", null ],
     [ "getFloatConstantList", "class_ogre_1_1_gpu_program_parameters.html#ad406754a4d98a6244bd5f3dd9d90b344", null ],
     [ "getFloatPointer", "class_ogre_1_1_gpu_program_parameters.html#ae6d8c8e89704ca66931bb7db6e32aae4", null ],
     [ "getFloatPointer", "class_ogre_1_1_gpu_program_parameters.html#ab27ff95b92e84751230148820a13ed8a", null ],
@@ -211,7 +208,6 @@ var class_ogre_1_1_gpu_program_parameters =
     [ "getIntConstantList", "class_ogre_1_1_gpu_program_parameters.html#ae1a836fec0e384915f8ff9bc41d55c17", null ],
     [ "getIntPointer", "class_ogre_1_1_gpu_program_parameters.html#a97c1e4434bba4bff4b8d3831c14888b8", null ],
     [ "getIntPointer", "class_ogre_1_1_gpu_program_parameters.html#ac0946c24e633b7de8a5a1db399a17f1f", null ],
-    [ "getUnsignedIntConstantList", "class_ogre_1_1_gpu_program_parameters.html#abd4585341519ee4d81fd2595e2601b03", null ],
     [ "getUnsignedIntPointer", "class_ogre_1_1_gpu_program_parameters.html#a8592e3a356a9ab6e0021ad8da223ff54", null ],
     [ "getUnsignedIntPointer", "class_ogre_1_1_gpu_program_parameters.html#ae1a41f7b9488180e77203fb060187614", null ],
     [ "getAutoConstantList", "class_ogre_1_1_gpu_program_parameters.html#a8c320bf1e446d8c1056908d7d3e2d5b5", null ],
@@ -223,7 +219,6 @@ var class_ogre_1_1_gpu_program_parameters =
     [ "clearAutoConstant", "class_ogre_1_1_gpu_program_parameters.html#af316990d01de4044abc25fe5c7e45290", null ],
     [ "setConstantFromTime", "class_ogre_1_1_gpu_program_parameters.html#a1f9b47a8a0af4fd4c8d4275817fa1d10", null ],
     [ "clearAutoConstants", "class_ogre_1_1_gpu_program_parameters.html#a679b87d628cce81ed181036782620251", null ],
-    [ "getAutoConstantIterator", "class_ogre_1_1_gpu_program_parameters.html#ad63af92d18cbb00913a0ceabd9f15385", null ],
     [ "getAutoConstants", "class_ogre_1_1_gpu_program_parameters.html#a00209358f6ca3428479a768c92c1a0cb", null ],
     [ "getAutoConstantCount", "class_ogre_1_1_gpu_program_parameters.html#afcd6ab088d420ce1edd2257e059259d8", null ],
     [ "getAutoConstantEntry", "class_ogre_1_1_gpu_program_parameters.html#ad5171ade96629c5517a42f84808cbd6d", null ],
@@ -262,7 +257,6 @@ var class_ogre_1_1_gpu_program_parameters =
     [ "_getFloatConstantPhysicalIndex", "class_ogre_1_1_gpu_program_parameters.html#aea8b02f3882228324aae14010ea164d8", null ],
     [ "_getDoubleConstantPhysicalIndex", "class_ogre_1_1_gpu_program_parameters.html#a52bb7eea97203e83be313932cc039c81", null ],
     [ "_getIntConstantPhysicalIndex", "class_ogre_1_1_gpu_program_parameters.html#a206c87883d74cc80ac24037b038e165a", null ],
-    [ "_getUnsignedIntConstantPhysicalIndex", "class_ogre_1_1_gpu_program_parameters.html#ae85bdc47948c7e8387ffc018b778ef21", null ],
     [ "setTransposeMatrices", "class_ogre_1_1_gpu_program_parameters.html#a8d64bde5a896b18fdd3a790746460633", null ],
     [ "getTransposeMatrices", "class_ogre_1_1_gpu_program_parameters.html#ad02acfaacda3b17dc59d401e118a86cb", null ],
     [ "copyConstantsFrom", "class_ogre_1_1_gpu_program_parameters.html#a0b59ddf1628a10109ba39eb832e24c6e", null ],
