@@ -7,8 +7,8 @@ var class_ogre_1_1_grid2_d_page_strategy =
     [ "destroyData", "class_ogre_1_1_grid2_d_page_strategy.html#afc81e88e7b9e9d4c1f176854989df84a", null ],
     [ "updateDebugDisplay", "class_ogre_1_1_grid2_d_page_strategy.html#a8a5b342c17f5009cfabf5171ea2c768a", null ],
     [ "getPageID", "class_ogre_1_1_grid2_d_page_strategy.html#a2e15c4764622887355d75b5b1a8cb10e", null ],
-    [ "getName", "class_ogre_1_1_grid2_d_page_strategy.html#a1b175f0b77c05ed13df9d917b71c6a31", null ],
-    [ "getManager", "class_ogre_1_1_grid2_d_page_strategy.html#a79dc7f55274f677dac8bf64798f4bbea", null ],
-    [ "frameStart", "class_ogre_1_1_grid2_d_page_strategy.html#adb6fc9f82a8ea955971b46c052a151af", null ],
-    [ "frameEnd", "class_ogre_1_1_grid2_d_page_strategy.html#a1990d8b1110ac0555e3ec18da77675b8", null ]
+    [ "getName", "class_ogre_1_1_grid2_d_page_strategy.html#ga1b175f0b77c05ed13df9d917b71c6a31", null ],
+    [ "getManager", "class_ogre_1_1_grid2_d_page_strategy.html#ga79dc7f55274f677dac8bf64798f4bbea", null ],
+    [ "frameStart", "class_ogre_1_1_grid2_d_page_strategy.html#gadb6fc9f82a8ea955971b46c052a151af", null ],
+    [ "frameEnd", "class_ogre_1_1_grid2_d_page_strategy.html#ga1990d8b1110ac0555e3ec18da77675b8", null ]
 ];
\ No newline at end of file
