@@ -20,14 +20,10 @@ var class_ogre_1_1_r_t_shader_1_1_function =
     [ "resolveLocalParameter", "class_ogre_1_1_r_t_shader_1_1_function.html#a4bad4a422742f2d73126303a6af9d229", null ],
     [ "getLocalParameter", "class_ogre_1_1_r_t_shader_1_1_function.html#a86212e62d4b7bfd8c6dc084dcd1f607f", null ],
     [ "getLocalParameter", "class_ogre_1_1_r_t_shader_1_1_function.html#ae4a22b20ed6ef533b5b887f1b11bf5f5", null ],
-    [ "getParameterByName", "class_ogre_1_1_r_t_shader_1_1_function.html#aec21080ad89536bd06422a30086b04f0", null ],
-    [ "getParameterBySemantic", "class_ogre_1_1_r_t_shader_1_1_function.html#a60c998404d977e84b9a04307a901c284", null ],
-    [ "getParameterByContent", "class_ogre_1_1_r_t_shader_1_1_function.html#a6cfbf42cd216217ed6ba2fc35628543d", null ],
     [ "getInputParameters", "class_ogre_1_1_r_t_shader_1_1_function.html#ad7a8f9bd962114f6edee9272c7fbb14c", null ],
     [ "getOutputParameters", "class_ogre_1_1_r_t_shader_1_1_function.html#a6d151ad6c47bfbb1506dc1e61f5ecfee", null ],
     [ "getLocalParameters", "class_ogre_1_1_r_t_shader_1_1_function.html#a89131308bfc3a2e6704dbac4f77c74ef", null ],
     [ "addAtomInstance", "class_ogre_1_1_r_t_shader_1_1_function.html#af11bf51a167028e8d69982e3972d9a65", null ],
-    [ "addAtomAssign", "class_ogre_1_1_r_t_shader_1_1_function.html#ae2a5cd9b8cc7176abc078b887d4196fd", null ],
     [ "getStage", "class_ogre_1_1_r_t_shader_1_1_function.html#a395e8d469a2b5d4656be2a8ae1a420d5", null ],
     [ "deleteAtomInstance", "class_ogre_1_1_r_t_shader_1_1_function.html#ad0a608d7e18cc52b284798816ba9edc7", null ],
     [ "getAtomInstances", "class_ogre_1_1_r_t_shader_1_1_function.html#a7b53f432b70912be1dcc07de9e6658cb", null ],
