@@ -128,5 +128,6 @@ var class_ogre_1_1_scene_node =
     [ "setUserAny", "class_ogre_1_1_scene_node.html#a2fdf947d54d8b67b5fef19d68da899ae", null ],
     [ "getUserAny", "class_ogre_1_1_scene_node.html#a9fa158a89aa8c4d8113ea52435eda1da", null ],
     [ "getUserObjectBindings", "class_ogre_1_1_scene_node.html#af3fcf16e43b07e046816125cbb8dc8f3", null ],
-    [ "getUserObjectBindings", "class_ogre_1_1_scene_node.html#aa154e07b616313f4c345ec6c0da635cd", null ]
+    [ "getUserObjectBindings", "class_ogre_1_1_scene_node.html#aa154e07b616313f4c345ec6c0da635cd", null ],
+    [ "SceneManager", "class_ogre_1_1_scene_node.html#a284464b0561a6f2915f04b0245b987f0", null ]
 ];
\ No newline at end of file
