@@ -516,6 +516,7 @@ var group___octree =
     [ "OctreeSceneManager", "class_ogre_1_1_octree_scene_manager.html", [
       [ "CameraList", "class_ogre_1_1_octree_scene_manager.html#a361c61a0f17ac50c8fd49bc0dd3ff622", null ],
       [ "AnimationList", "class_ogre_1_1_octree_scene_manager.html#a260738557c9a32aed8d5ca14c28d300f", null ],
+      [ "MovableObjectMap", "class_ogre_1_1_octree_scene_manager.html#a317d0ca0b29d739ed54b4422f850b629", null ],
       [ "CameraIterator", "class_ogre_1_1_octree_scene_manager.html#a22fcb8a9ddb7efe79d053a975a685111", null ],
       [ "AnimationIterator", "class_ogre_1_1_octree_scene_manager.html#a3a720414f68274bb9c5026911e27135d", null ],
       [ "MovableObjectIterator", "class_ogre_1_1_octree_scene_manager.html#a4249682ae2a69255ed225383d930aec1", null ],
@@ -808,6 +809,7 @@ var group___octree =
       [ "destroyAllMovableObjects", "class_ogre_1_1_octree_scene_manager.html#aa15b95a642dd9553498cba260ca160d8", null ],
       [ "getMovableObject", "class_ogre_1_1_octree_scene_manager.html#a6b086877b0ae9f45cd4c85ab2e7492c5", null ],
       [ "hasMovableObject", "class_ogre_1_1_octree_scene_manager.html#a7179987953e8b7889610ab469637bd93", null ],
+      [ "getMovableObjects", "class_ogre_1_1_octree_scene_manager.html#a43aa8a7ff4199f380ead80aa0d741eeb", null ],
       [ "getMovableObjectIterator", "class_ogre_1_1_octree_scene_manager.html#a09e912c708107f9432565bff39ba4b63", null ],
       [ "injectMovableObject", "class_ogre_1_1_octree_scene_manager.html#a1eaa9f147fe2c97f159ffa1896a1be88", null ],
       [ "extractMovableObject", "class_ogre_1_1_octree_scene_manager.html#a326e7192cb5d4cc36c035f1a1dfa01a5", null ],
