@@ -208,6 +208,8 @@ var namespace_ogre =
     [ "DistanceLodBoxStrategy", "class_ogre_1_1_distance_lod_box_strategy.html", "class_ogre_1_1_distance_lod_box_strategy" ],
     [ "DistanceLodSphereStrategy", "class_ogre_1_1_distance_lod_sphere_strategy.html", "class_ogre_1_1_distance_lod_sphere_strategy" ],
     [ "DistanceLodStrategyBase", "class_ogre_1_1_distance_lod_strategy_base.html", "class_ogre_1_1_distance_lod_strategy_base" ],
+    [ "DotSceneLoader", "class_ogre_1_1_dot_scene_loader.html", "class_ogre_1_1_dot_scene_loader" ],
+    [ "DotScenePlugin", "class_ogre_1_1_dot_scene_plugin.html", null ],
     [ "DriverVersion", "struct_ogre_1_1_driver_version.html", "struct_ogre_1_1_driver_version" ],
     [ "DualQuaternion", "class_ogre_1_1_dual_quaternion.html", "class_ogre_1_1_dual_quaternion" ],
     [ "DynLib", "class_ogre_1_1_dyn_lib.html", "class_ogre_1_1_dyn_lib" ],
@@ -727,6 +729,8 @@ var namespace_ogre =
     [ "SPFMNone", "struct_ogre_1_1_s_p_f_m_none.html", "struct_ogre_1_1_s_p_f_m_none" ],
     [ "Sphere", "class_ogre_1_1_sphere.html", "class_ogre_1_1_sphere" ],
     [ "SphereSceneQuery", "class_ogre_1_1_sphere_scene_query.html", "class_ogre_1_1_sphere_scene_query" ],
+    [ "SPIRVShader", "class_ogre_1_1_s_p_i_r_v_shader.html", "class_ogre_1_1_s_p_i_r_v_shader" ],
+    [ "SPIRVShaderFactory", "class_ogre_1_1_s_p_i_r_v_shader_factory.html", "class_ogre_1_1_s_p_i_r_v_shader_factory" ],
     [ "StaticCache", "class_ogre_1_1_static_cache.html", "class_ogre_1_1_static_cache" ],
     [ "StaticFaceGroup", "struct_ogre_1_1_static_face_group.html", "struct_ogre_1_1_static_face_group" ],
     [ "StaticGeometry", "class_ogre_1_1_static_geometry.html", "class_ogre_1_1_static_geometry" ],
@@ -776,8 +780,8 @@ var namespace_ogre =
     [ "UnimplementedException", "class_ogre_1_1_unimplemented_exception.html", "class_ogre_1_1_unimplemented_exception" ],
     [ "UserObjectBindings", "class_ogre_1_1_user_object_bindings.html", "class_ogre_1_1_user_object_bindings" ],
     [ "VariableAccessAbstractNode", "class_ogre_1_1_variable_access_abstract_node.html", "class_ogre_1_1_variable_access_abstract_node" ],
-    [ "vector", "struct_ogre_1_1vector.html", "struct_ogre_1_1vector" ],
     [ "Vector", "class_ogre_1_1_vector.html", "class_ogre_1_1_vector" ],
+    [ "vector", "struct_ogre_1_1vector.html", "struct_ogre_1_1vector" ],
     [ "VectorBase", "struct_ogre_1_1_vector_base.html", "struct_ogre_1_1_vector_base" ],
     [ "VectorBase< 2, Real >", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4" ],
     [ "VectorBase< 3, Real >", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4" ],
